@@ -38,11 +38,8 @@ tbl_format_header.tbl <- function(x, setup, ...) {
     header <- named_header
   } else {
     header <- paste0(
-      justify(
-        paste0(names2(named_header), ":"),
-        right = FALSE, space = NBSP
-      ),
-      # We add a space after the NBSP inserted by justify()
+      align(paste0(names2(named_header), ":"), space = NBSP),
+      # We add a space after the NBSP inserted by align()
       # so that wrapping occurs at the right location for very narrow outputs
       " ",
       named_header
@@ -59,18 +56,3 @@ tbl_format_header.pillar_tbl_format_setup <- function(x, ...) {
     tbl_format_header(x$x, setup = x)
   ))
 }
-
-justify <- function(x, right = TRUE, space = " ") {
-  if (length(x) == 0L) {
-    return(character())
-  }
-  width <- nchar(x, type = "width")
-  max_width <- max(width)
-  spaces_template <- paste(rep(space, max_width), collapse = "")
-  spaces <- map_chr(max_width - width, substr, x = spaces_template, start = 1L)
-  if (right) {
-    paste0(spaces, x)
-  } else {
-    paste0(x, spaces)
-  }
-}
